package com.install4j.api.windows;

import com.install4j.runtime.installer.platform.win32.FolderInfo;

/**
 * Enumeration class for the different special system folders in Microsoft Windows.

 * @author ej-technologies GmbH
 */
public enum SpecialFolder {
    /**
     * Identifies the file system directory used to physically store file objects on the desktop.
     * A typical path is <tt>C:\Documents and Settings\<i>user name</i>\Desktop</tt> on Windows XP and earlier
     * or <tt>C:\Users\<i>user name</i>\Desktop</tt> on Windows Vista and later.
     */
    DESKTOP(FolderInfo.FOLDER_DESKTOP),

    /**
     * Identifies the file system directory containing Start menu items.
     * A typical path is <tt>C:\Documents and Settings\<i>user name</i>\Start Menu</tt> on Windows XP and earlier
     * or <tt>C:\Users\<i>user name</i>\AppData\Roaming\Microsoft\Windows\Start Menu</tt> on Windows Vista and later.
     */
    STARTMENU(FolderInfo.FOLDER_STARTMENU),

    /**
     * Identifies the file system directory that contains the user's program groups.
     * The groups are themselves file system directories.
     * A typical path is <tt>C:\Documents and Settings\<i>user name</i>\Start Menu\Programs</tt> on Windows XP and earlier
     * or <tt>C:\Users\<i>user name</i>\AppData\Roaming\Microsoft\Windows\Start Menu\Programs</tt> on Windows Vista and later.
     */
    PROGRAMS(FolderInfo.FOLDER_PROGRAMS),

    /**
     * Identifies the file system directory that corresponds to the user's Startup program group.
     * The system starts these programs whenever any user logs onto Windows NT or starts Windows 95.
     * A typical path is <tt>C:\Documents and Settings\<i>user name</i>\Start Menu\Programs\Startup</tt> on Windows XP and earlier
     * or <tt>C:\Users\<i>user name</i>\AppData\Roaming\Microsoft\Windows\Start Menu\Programs\Startup</tt> on Windows Vista and later.
     */
    STARTUP(FolderInfo.FOLDER_STARTUP),

    /**
     * Identifies the file system directory that contains Send To menu items.
     * A typical path is <tt>C:\Documents and Settings\<i>user name</i>\SendTo</tt> on Windows XP and earlier
     * or <tt>C:\Users\<i>user name</i>\AppData\Roaming\Microsoft\Windows\SendTo</tt> on Windows Vista and later.
     */
    SENDTO(FolderInfo.FOLDER_SENDTO),

    /**
     * Identifies a virtual folder containing fonts.
     * A typical path is <tt>C:\Windows\Fonts</tt>.
     */
    FONTS(FolderInfo.FOLDER_FONTS),

    /**
     * Identifies the file system directory that serves as a common repository for application-specific data.
     * A typical path is <tt>C:\Documents and Settings\<i>user name</i>\Application Data</tt> on Windows XP and earlier
     * or <tt>C:\Users\<i>user name</i>\AppData\Roaming</tt> on Windows Vista and later.
     */
    APPDATA(FolderInfo.FOLDER_APPDATA),

    /**
     * Identifies the file system directory used to physically store a user's common repository of documents.
     * A typical path is <tt>C:\Documents and Settings\<i>user name</i>\My Documents</tt> on Windows XP and earlier
     * or <tt>C:\Users\<i>user name</i>\Documents</tt> on Windows Vista and later.
     */
    DOCS(FolderInfo.FOLDER_DOCS),

    /**
     * Identifies the file system directory that serves as a common repository for document templates.
     * A typical path is <tt>C:\Documents and Settings\<i>user name</i>\Templates</tt> on Windows XP and earlier
     * or <tt>C:\Users\<i>user name</i>\AppData\Roaming\Microsoft\Windows\Templates</tt> on Windows Vista and later.
     */
    TEMPLATES(FolderInfo.FOLDER_TEMPLATES),

    /**
     * Identifies the file system directory that serves as a common repository for the user's favorite items.
     * A typical path is <tt>C:\Documents and Settings\<i>user name</i>\Favorites</tt>.
     */
    FAVORITES(FolderInfo.FOLDER_FAVORITES),

    /**
     * Identifies the file system directory that serves as a data repository for local applications.
     * A typical path is <tt>C:\Documents and Settings\<i>user name</i>\Local Settings\Application Data</tt> on Windows XP and earlier
     * or <tt>C:\Users\<i>user name</i>\AppData\Local</tt> on Windows Vista and later.
     */
    LOCAL_APPDATA(FolderInfo.FOLDER_LOCAL_APPDATA);

    private int intValue;

    SpecialFolder(int intValue) {
        this.intValue = intValue;
    }

    int getIntValue() {
        return intValue;
    }


}
